# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/nelskate/herbal_product/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Nelskate\\HerbalProduct\\": "packages/nelskate/herbal_product/src",
            "Nelskate\\HerbalProduct\\Seeders\\": "packages/nelskate/herbal_product/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Nelskate\HerbalProduct\Providers\HerbalProductServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'HerbalProduct'  => Nelskate\HerbalProduct\Facades\HerbalProduct::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Nelskate\\HerbalProduct\\Seeders\\HerbalProductTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Nelskate\HerbalProduct\Providers\HerbalProductServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Nelskate\HerbalProduct\Providers\HerbalProductServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Nelskate\HerbalProduct\Providers\HerbalProductServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/herbal_product/{modulename}

**User**

    http://path-to-route-folder/user/herbal_product/{modulename}

**Public**

    http://path-to-route-folder/herbal_products


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/herbal_product/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/herbal_product/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/herbal_product/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/herbal_product/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/herbal_product/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/herbal_product/{modulename}/{slug}
    METHOD: GET